@@ -84,17 +84,66 @@ function FieldTable(spec) {
         }
 
         if (typeof(me.spec.fetch) === 'string') {
-            t2hui.fetch(me.spec.fetch, {}, me.render_item);
+            t2hui.fetch(me.spec.fetch, {done: me.make_sortable}, me.render_item);
         }
         else if (typeof(me.spec.fetch) === 'object') {
             me.spec.fetch.forEach(me.render_item);
+            if (me.spec.fetch.length > 1) {
+                me.make_sortable();
+            }
         }
 
         var wrapper = $('<div id="' + spec.id + '" class="field-table-wrapper ' + spec.class + '"></div>');
         wrapper.append(me.table);
+
         return wrapper;
     }
 
+    me.make_sortable = function() {
+        if (!me.spec.sortable) { return }
+
+        var them = me.table.children('thead').children('tr').first().children('th');
+
+        them.click(function() {
+            $(this).addClass('sorting');
+        });
+
+        var x = me.table.tablesort({
+            'compare': function(a, b) {
+                var an = parseFloat(a);
+                var bn = parseFloat(b);
+
+                if (!isNaN(an) && !isNaN(bn)) {
+                    if (an > bn) {
+                        return 1;
+                    } else if (an < bn) {
+                        return -1;
+                    } else {
+                        return 0;
+                    }
+                }
+                if (!isNaN(an)) {
+                    return 1;
+                }
+                if (!isNaN(bn)) {
+                    return -1;
+                }
+
+                if (a > b) {
+                    return 1;
+                } else if (a < b) {
+                    return -1;
+                } else {
+                    return 0;
+                }
+            }
+        });
+
+        me.table.on('tablesort:complete', function() {
+            them.removeClass('sorting');
+        })
+    }
+
     me.render_item = function(item) {
         if (me.spec.expand_item) {
             var list = me.spec.expand_item(item);
@@ -130,39 +179,6 @@ function FieldTable(spec) {
 
         row.index = me.rows.length;
         me.rows.push(row);
-
-        if (me.spec.sortable) {
-            me.table.tablesort({
-                'compare': function(a, b) {
-                    var an = parseFloat(a);
-                    var bn = parseFloat(b);
-
-                    if (!isNaN(an) && !isNaN(bn)) {
-                        if (an > bn) {
-                            return 1;
-                        } else if (an < bn) {
-                            return -1;
-                        } else {
-                            return 0;
-                        }
-                    }
-                    if (!isNaN(an)) {
-                        return 1;
-                    }
-                    if (!isNaN(bn)) {
-                        return -1;
-                    }
-
-                    if (a > b) {
-                        return 1;
-                    } else if (a < b) {
-                        return -1;
-                    } else {
-                        return 0;
-                    }
-                }
-            });
-        }
     }
 
     me.render_row = function(item) {
@@ -189,7 +205,6 @@ function FieldTable(spec) {
 
         me.dynamic_columns.forEach(function(header) {
             var name = header.attr('data-dynamic-name');
-            console.log(name, header);
             var col = $('<td class="col-' + name + '"></td>');
             row.html.append(col);
             row.dynamic_columns.push(col);
@@ -240,7 +255,6 @@ function FieldTable(spec) {
     }
 
     me.render_dynamic_col = function(field, name) {
-        console.log(name);
         var col = $('<td class="col-' + name + '">' + field.details + '</td>');
 
         if (field.data) {
